@@ -268,7 +268,7 @@ WenF<-function(pheRaw=NULL,genRaw=NULL,mapRaw1=NULL,yygg1=NULL,cov_en=NULL,
 
 
 
-WenS<-function(flag=NULL,CriLOD=NULL,NUM=NULL,pheRaw=NULL,Likelihood=NULL,
+WenS<-function(flag=NULL,CriLOD=NULL,NUM=NULL,pheRaw=NULL,Likelihood=NULL,SetSeed=NULL,
                flagrqtl=NULL,yygg=NULL,mx=NULL,phe=NULL,chr_name=NULL,v.map=NULL,
                gen.raw=NULL,a.gen.orig=NULL,d.gen.orig=NULL,n=NULL,
                names.insert2=NULL,X.ad.tran.data=NULL,X.ad.t4=NULL,dir=NULL){
@@ -1397,6 +1397,123 @@ WenS<-function(flag=NULL,CriLOD=NULL,NUM=NULL,pheRaw=NULL,Likelihood=NULL,
     return (list(lod=lod,ps=ps))
   }
   
+  adalasso<-function(X, y,k=10,use.Gram=TRUE,both=TRUE,intercept=TRUE){
+    colnames(X)=1:ncol(X)
+    n<-length(y)
+    cv.adalasso<-NULL
+    globalfit<-mylars(X,y,k=k,use.Gram=use.Gram,normalize=TRUE,intercept=intercept)
+    coefficients.lasso=globalfit$coefficients
+    intercept.lasso=globalfit$intercept
+    cv.lasso<-globalfit$cv.lasso
+    lambda<-globalfit$lambda
+    lambda.lasso<-globalfit$lambda.opt
+    coefficients.adalasso=NULL
+    lambda.adalasso<-intercept.adalasso<-NULL
+    if (use.Gram==TRUE){
+      type="covariance"
+    }
+    if (use.Gram==FALSE){
+      type="naive"
+    }
+    if (both==TRUE){ 
+      # cross-validation for adaptive lasso
+      #set.seed(11001)
+      all.folds <- split(sample(1:n),rep(1:k,length=n))
+      residmat <- matrix(0, length(lambda), k)
+      
+      for (i in seq(k)) {
+        omit <- all.folds[[i]]
+        Xtrain<-X[-omit,,drop=FALSE]
+        ytrain<-y[-omit]
+        Xtest<-X[omit,,drop=FALSE]
+        ytest<-y[omit]
+        my.lars<-mylars(Xtrain,ytrain,k=k,normalize=TRUE,use.Gram=use.Gram,intercept=intercept)
+        coef.lasso<-my.lars$coefficients
+        weights <- 1/abs(coef.lasso[ abs(coef.lasso)>0 ])
+        #cat(paste("-- non-zero weights ",length(weights),"\n"))
+        if (length(weights)==0){
+          residmat[,i]<-mean((mean(ytrain)-ytest)^2)
+        }
+        if (length(weights)==1){
+          residmat[,i]=mean((ytest -my.lars$intercept - Xtest%*%coef.lasso)^2)
+        }
+        if (length(weights)>1){
+          XXtrain <- Xtrain[ , names(weights), drop=FALSE]
+          XXtest<-Xtest[ , names(weights), drop=FALSE]
+          XXtrain <- scale(XXtrain, center=FALSE, scale=weights)
+          XXtest<-scale(XXtest, center=FALSE, scale=weights)
+          #cat(paste("ncol of XXtrain: ",ncol(XXtrain),"\n"))
+          fit<-glmnet(XXtrain,ytrain,type.gaussian=type,standardize=FALSE,intercept=intercept)
+          pred<-predict(fit, newx=XXtest, type = "response",s = lambda)
+          if (length(omit) == 1){
+            pred <- matrix(pred, nrow = 1)
+          }
+          residmat[, i] <- apply((ytest - pred)^2, 2, mean)
+        }
+      }
+      cv <- apply(residmat, 1, mean)
+      cv.adalasso<-min(cv)
+      weights <- 1/abs(coefficients.lasso[ abs(coefficients.lasso)>0 ])
+      coefficients.adalasso<-rep(0,ncol(X))
+      names(coefficients.adalasso)<-1:ncol(X)
+      if (length(weights)>0){
+        XX <- X[ , names(weights), drop=FALSE]
+        if ( length(weights)==1 )  XX <- XX/weights        
+        else  XX <- scale(XX, center=FALSE, scale=weights)
+        if (length(weights)<=1){
+          intercept.adalasso=intercept.lasso 
+          coefficients.adalasso<-coefficients.lasso
+          lambda.adalasso=0
+        }
+        else{
+          fit<-glmnet(XX,y,type.gaussian=type,standardize=FALSE,intercept=intercept)
+          lambda.adalasso<-lambda[which.min(cv)]
+          coefficients=predict(fit,type="coefficients",s=lambda.adalasso)
+          intercept.adalasso<-coefficients[1]
+          coefficients.adalasso[names(weights)]<-coefficients[-1]/weights
+        }
+      }
+    }
+    return(list(cv.lasso=cv.lasso,lambda.lasso=lambda.lasso,cv.adalasso=cv.adalasso,lambda.adalasso=lambda.adalasso,intercept.lasso=intercept.lasso, intercept.adalasso=intercept.adalasso, coefficients.lasso=coefficients.lasso,coefficients.adalasso=coefficients.adalasso))
+  }
+  
+  mylars<-function (X, y, k = 10,use.Gram=TRUE,normalize=TRUE,intercept=TRUE) 
+  {
+    x<-X
+    n<-length(y)
+    # set.seed(11001)
+    all.folds <- split(sample(1:n),rep(1:k,length=n))
+    
+    if (use.Gram==TRUE){
+      type="covariance"
+    }
+    if (use.Gram==FALSE){
+      type="naive"
+    }
+    globalfit<-glmnet(x,y,family="gaussian",standardize=normalize,type.gaussian=type,intercept=intercept)
+    lambda<-globalfit$lambda
+    residmat <- matrix(0, length(lambda), k)
+    for (i in seq(k)) {
+      omit <- all.folds[[i]]
+      fit <- glmnet(x[-omit, ,drop=FALSE], y[-omit],type.gaussian=type,standardize=normalize,family="gaussian",intercept=intercept)
+      fit <- predict(fit, newx=x[omit, , drop = FALSE], type = "response", 
+                     s = lambda)
+      if (length(omit) == 1) 
+        fit <- matrix(fit, nrow = 1)
+      residmat[, i] <- apply((y[omit] - fit)^2, 2, mean)
+    }
+    cv <- apply(residmat, 1, mean)
+    cv.lasso<-min(cv)
+    cv.error <- sqrt(apply(residmat, 1, var)/k)
+    lambda.opt<-lambda[which.min(cv)]
+    coefficients=predict(globalfit,type="coefficients",s=lambda.opt)
+    inter=coefficients[1]
+    coefficients=coefficients[-1]
+    names(coefficients)=1:ncol(X)
+    object <- list(lambda=lambda,cv=cv,lambda.opt=lambda.opt,cv.lasso=cv.lasso,intercept=inter,coefficients=coefficients)
+    invisible(object)
+  }
+  
     mxmp<-mx[,1:2]
     rownames(mxmp)<-NULL
     mxmp<-as.data.frame(mxmp,stringsAsFactors = F)
@@ -1464,8 +1581,10 @@ WenS<-function(flag=NULL,CriLOD=NULL,NUM=NULL,pheRaw=NULL,Likelihood=NULL,
     #########################################3
     xdata.ad<-X.ad.t4[id.ind,ad.eb.loc.0]
     X.ad.eb.names.0<-X.ad.tran.data[ad.eb.loc.0,1:8]
-    
-    set.seed(11001)  #user's options
+   
+    suppressWarnings(RNGkind(sample.kind = "Rounding"))
+    set.seed(SetSeed)  #user's options
+
     model1<-adalasso(X=xdata.ad,y=Y.part.1,k=10,use.Gram = T,both=T)
     adalasso.beta<-model1$coefficients.adalasso
     
